# coding: utf-8

"""
AuthorizationApi.py
Copyright 2016 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
"""

from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class AuthorizationApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def delete_roles_role_id(self, role_id, **kwargs):
        """
        Delete an organization role.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_roles_role_id(role_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str role_id: Role ID (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['role_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_roles_role_id" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'role_id' is set
        if ('role_id' not in params) or (params['role_id'] is None):
            raise ValueError("Missing the required parameter `role_id` when calling `delete_roles_role_id`")


        resource_path = '/api/v2/authorization/roles/{roleId}'.replace('{format}', 'json')
        path_params = {}
        if 'role_id' in params:
            path_params['roleId'] = params['role_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'DELETE',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type=None,
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def delete_user_id_roles(self, user_id, **kwargs):
        """
        Removes all the roles from the user.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_user_id_roles(user_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str user_id: User ID (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_user_id_roles" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'user_id' is set
        if ('user_id' not in params) or (params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `delete_user_id_roles`")


        resource_path = '/api/v2/users/{userId}/roles'.replace('{format}', 'json')
        path_params = {}
        if 'user_id' in params:
            path_params['userId'] = params['user_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'DELETE',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type=None,
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_permissions(self, **kwargs):
        """
        Get all permissions.
        Retrieve a list of all permission defined in the system.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_permissions(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int page_size: Page size
        :param int page_number: Page number
        :return: PermissionCollectionEntityListing
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['page_size', 'page_number']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_permissions" % key
                )
            params[key] = val
        del params['kwargs']



        resource_path = '/api/v2/authorization/permissions'.replace('{format}', 'json')
        path_params = {}

        query_params = {}
        if 'page_size' in params:
            query_params['pageSize'] = params['page_size']
        if 'page_number' in params:
            query_params['pageNumber'] = params['page_number']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='PermissionCollectionEntityListing',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_products(self, **kwargs):
        """
        Get the list of enabled products
        Gets the list of enabled products. Some example product names are: collaborateFree, collaboratePro, communicate, and engage.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_products(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :return: OrganizationProductEntityListing
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_products" % key
                )
            params[key] = val
        del params['kwargs']



        resource_path = '/api/v2/authorization/products'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='OrganizationProductEntityListing',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_roles(self, **kwargs):
        """
        Retrieve a list of all roles defined for the organization
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_roles(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int page_size: The total page size requested
        :param int page_number: The page number requested
        :param str sort_by: variable name requested to sort by
        :param list[str] expand: variable name requested by expand list
        :param str next_page: next page token
        :param str previous_page: Previous page token
        :param list[str] permission: 
        :param bool user_count: 
        :return: OrganizationRoleEntityListing
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['page_size', 'page_number', 'sort_by', 'expand', 'next_page', 'previous_page', 'permission', 'user_count']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_roles" % key
                )
            params[key] = val
        del params['kwargs']



        resource_path = '/api/v2/authorization/roles'.replace('{format}', 'json')
        path_params = {}

        query_params = {}
        if 'page_size' in params:
            query_params['pageSize'] = params['page_size']
        if 'page_number' in params:
            query_params['pageNumber'] = params['page_number']
        if 'sort_by' in params:
            query_params['sortBy'] = params['sort_by']
        if 'expand' in params:
            query_params['expand'] = params['expand']
        if 'next_page' in params:
            query_params['nextPage'] = params['next_page']
        if 'previous_page' in params:
            query_params['previousPage'] = params['previous_page']
        if 'permission' in params:
            query_params['permission'] = params['permission']
        if 'user_count' in params:
            query_params['userCount'] = params['user_count']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='OrganizationRoleEntityListing',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_roles_leftrole_id_comparedefault_rightrole_id(self, left_role_id, right_role_id, **kwargs):
        """
        Get an org role to default role comparison comparison
        Compares any organization role to a default role id and show differences

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_roles_leftrole_id_comparedefault_rightrole_id(left_role_id, right_role_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str left_role_id: Left Role ID (required)
        :param str right_role_id: Right Role id (required)
        :return: DomainOrgRoleDifference
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['left_role_id', 'right_role_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_roles_leftrole_id_comparedefault_rightrole_id" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'left_role_id' is set
        if ('left_role_id' not in params) or (params['left_role_id'] is None):
            raise ValueError("Missing the required parameter `left_role_id` when calling `get_roles_leftrole_id_comparedefault_rightrole_id`")
        # verify the required parameter 'right_role_id' is set
        if ('right_role_id' not in params) or (params['right_role_id'] is None):
            raise ValueError("Missing the required parameter `right_role_id` when calling `get_roles_leftrole_id_comparedefault_rightrole_id`")


        resource_path = '/api/v2/authorization/roles/{leftRoleId}/comparedefault/{rightRoleId}'.replace('{format}', 'json')
        path_params = {}
        if 'left_role_id' in params:
            path_params['leftRoleId'] = params['left_role_id']
        if 'right_role_id' in params:
            path_params['rightRoleId'] = params['right_role_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='DomainOrgRoleDifference',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_roles_role_id(self, role_id, **kwargs):
        """
        Get a single organization role.
        Get the organization role specified by its ID.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_roles_role_id(role_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str role_id: Role ID (required)
        :return: DomainOrganizationRole
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['role_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_roles_role_id" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'role_id' is set
        if ('role_id' not in params) or (params['role_id'] is None):
            raise ValueError("Missing the required parameter `role_id` when calling `get_roles_role_id`")


        resource_path = '/api/v2/authorization/roles/{roleId}'.replace('{format}', 'json')
        path_params = {}
        if 'role_id' in params:
            path_params['roleId'] = params['role_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='DomainOrganizationRole',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_user_id_roles(self, user_id, **kwargs):
        """
        Returns a listing of roles and permissions for a user.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_user_id_roles(user_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str user_id: User ID (required)
        :return: UserAuthorization
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_user_id_roles" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'user_id' is set
        if ('user_id' not in params) or (params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `get_user_id_roles`")


        resource_path = '/api/v2/users/{userId}/roles'.replace('{format}', 'json')
        path_params = {}
        if 'user_id' in params:
            path_params['userId'] = params['user_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='UserAuthorization',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def patch_roles_role_id(self, role_id, body, **kwargs):
        """
        Patch Organization Role for needsUpdate Field
        Patch Organization Role for needsUpdate Field

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.patch_roles_role_id(role_id, body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str role_id: Role ID (required)
        :param DomainOrganizationRole body: Organization role (required)
        :return: DomainOrganizationRole
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['role_id', 'body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method patch_roles_role_id" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'role_id' is set
        if ('role_id' not in params) or (params['role_id'] is None):
            raise ValueError("Missing the required parameter `role_id` when calling `patch_roles_role_id`")
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `patch_roles_role_id`")


        resource_path = '/api/v2/authorization/roles/{roleId}'.replace('{format}', 'json')
        path_params = {}
        if 'role_id' in params:
            path_params['roleId'] = params['role_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'PATCH',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='DomainOrganizationRole',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def post_roles(self, body, **kwargs):
        """
        Create an organization role.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.post_roles(body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param DomainOrganizationRole body: Organization role (required)
        :return: DomainOrganizationRole
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_roles" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_roles`")


        resource_path = '/api/v2/authorization/roles'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='DomainOrganizationRole',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def post_roles_default(self, **kwargs):
        """
        Restores all default roles
        This endpoint serves several purposes. 1. It provides the org with default roles. This is important for default roles that will be added after go-live (they can retroactively add the new default-role). Note: When not using a query param of force=true, it only adds the default roles not configured for the org; it does not overwrite roles. 2. Using the query param force=true, you can restore all default roles. Note: This does not have an effect on custom roles.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.post_roles_default(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param bool force: Restore default roles
        :return: OrganizationRoleEntityListing
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['force']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_roles_default" % key
                )
            params[key] = val
        del params['kwargs']



        resource_path = '/api/v2/authorization/roles/default'.replace('{format}', 'json')
        path_params = {}

        query_params = {}
        if 'force' in params:
            query_params['force'] = params['force']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='OrganizationRoleEntityListing',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def post_roles_leftrole_id_comparedefault_rightrole_id(self, left_role_id, right_role_id, body, **kwargs):
        """
        Get an unsaved org role to default role comparison
        Allows users to compare their existing roles in an unsaved state to its default role

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.post_roles_leftrole_id_comparedefault_rightrole_id(left_role_id, right_role_id, body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str left_role_id: Left Role ID (required)
        :param str right_role_id: Right Role id (required)
        :param DomainOrganizationRole body: Organization role (required)
        :return: DomainOrgRoleDifference
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['left_role_id', 'right_role_id', 'body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_roles_leftrole_id_comparedefault_rightrole_id" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'left_role_id' is set
        if ('left_role_id' not in params) or (params['left_role_id'] is None):
            raise ValueError("Missing the required parameter `left_role_id` when calling `post_roles_leftrole_id_comparedefault_rightrole_id`")
        # verify the required parameter 'right_role_id' is set
        if ('right_role_id' not in params) or (params['right_role_id'] is None):
            raise ValueError("Missing the required parameter `right_role_id` when calling `post_roles_leftrole_id_comparedefault_rightrole_id`")
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_roles_leftrole_id_comparedefault_rightrole_id`")


        resource_path = '/api/v2/authorization/roles/{leftRoleId}/comparedefault/{rightRoleId}'.replace('{format}', 'json')
        path_params = {}
        if 'left_role_id' in params:
            path_params['leftRoleId'] = params['left_role_id']
        if 'right_role_id' in params:
            path_params['rightRoleId'] = params['right_role_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='DomainOrgRoleDifference',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def put_roles_default(self, body, **kwargs):
        """
        Restore specified default roles
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.put_roles_default(body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param list[DomainOrganizationRole] body: Organization roles list (required)
        :return: OrganizationRoleEntityListing
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_roles_default" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `put_roles_default`")


        resource_path = '/api/v2/authorization/roles/default'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'PUT',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='OrganizationRoleEntityListing',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def put_roles_role_id(self, role_id, body, **kwargs):
        """
        Update an organization role.
        Update

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.put_roles_role_id(role_id, body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str role_id: Role ID (required)
        :param DomainOrganizationRole body: Organization role (required)
        :return: DomainOrganizationRole
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['role_id', 'body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_roles_role_id" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'role_id' is set
        if ('role_id' not in params) or (params['role_id'] is None):
            raise ValueError("Missing the required parameter `role_id` when calling `put_roles_role_id`")
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `put_roles_role_id`")


        resource_path = '/api/v2/authorization/roles/{roleId}'.replace('{format}', 'json')
        path_params = {}
        if 'role_id' in params:
            path_params['roleId'] = params['role_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'PUT',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='DomainOrganizationRole',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def put_roles_role_id_users_add(self, role_id, body, **kwargs):
        """
        Sets the users for the role
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.put_roles_role_id_users_add(role_id, body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str role_id: Role ID (required)
        :param list[str] body: List of user IDs (required)
        :return: list[str]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['role_id', 'body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_roles_role_id_users_add" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'role_id' is set
        if ('role_id' not in params) or (params['role_id'] is None):
            raise ValueError("Missing the required parameter `role_id` when calling `put_roles_role_id_users_add`")
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `put_roles_role_id_users_add`")


        resource_path = '/api/v2/authorization/roles/{roleId}/users/add'.replace('{format}', 'json')
        path_params = {}
        if 'role_id' in params:
            path_params['roleId'] = params['role_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'PUT',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='list[str]',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def put_roles_role_id_users_remove(self, role_id, body, **kwargs):
        """
        Removes the users from the role
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.put_roles_role_id_users_remove(role_id, body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str role_id: Role ID (required)
        :param list[str] body: List of user IDs (required)
        :return: list[str]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['role_id', 'body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_roles_role_id_users_remove" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'role_id' is set
        if ('role_id' not in params) or (params['role_id'] is None):
            raise ValueError("Missing the required parameter `role_id` when calling `put_roles_role_id_users_remove`")
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `put_roles_role_id_users_remove`")


        resource_path = '/api/v2/authorization/roles/{roleId}/users/remove'.replace('{format}', 'json')
        path_params = {}
        if 'role_id' in params:
            path_params['roleId'] = params['role_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'PUT',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='list[str]',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def put_user_id_roles(self, user_id, body, **kwargs):
        """
        Sets the user's roles
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.put_user_id_roles(user_id, body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str user_id: User ID (required)
        :param list[str] body: List of roles (required)
        :return: UserAuthorization
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id', 'body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_user_id_roles" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'user_id' is set
        if ('user_id' not in params) or (params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `put_user_id_roles`")
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `put_user_id_roles`")


        resource_path = '/api/v2/users/{userId}/roles'.replace('{format}', 'json')
        path_params = {}
        if 'user_id' in params:
            path_params['userId'] = params['user_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'PUT',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='UserAuthorization',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response



# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class PhoneCapabilities(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        PhoneCapabilities - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'provisions': 'bool',
            'registers': 'bool',
            'dual_registers': 'bool',
            'hardware_id_type': 'str',
            'allow_reboot': 'bool',
            'no_rebalance': 'bool'
        }

        self.attribute_map = {
            'provisions': 'provisions',
            'registers': 'registers',
            'dual_registers': 'dualRegisters',
            'hardware_id_type': 'hardwareIdType',
            'allow_reboot': 'allowReboot',
            'no_rebalance': 'noRebalance'
        }

        self._provisions = False
        self._registers = False
        self._dual_registers = False
        self._hardware_id_type = None
        self._allow_reboot = False
        self._no_rebalance = False

    @property
    def provisions(self):
        """
        Gets the provisions of this PhoneCapabilities.


        :return: The provisions of this PhoneCapabilities.
        :rtype: bool
        """
        return self._provisions

    @provisions.setter
    def provisions(self, provisions):
        """
        Sets the provisions of this PhoneCapabilities.


        :param provisions: The provisions of this PhoneCapabilities.
        :type: bool
        """
        
        self._provisions = provisions

    @property
    def registers(self):
        """
        Gets the registers of this PhoneCapabilities.


        :return: The registers of this PhoneCapabilities.
        :rtype: bool
        """
        return self._registers

    @registers.setter
    def registers(self, registers):
        """
        Sets the registers of this PhoneCapabilities.


        :param registers: The registers of this PhoneCapabilities.
        :type: bool
        """
        
        self._registers = registers

    @property
    def dual_registers(self):
        """
        Gets the dual_registers of this PhoneCapabilities.


        :return: The dual_registers of this PhoneCapabilities.
        :rtype: bool
        """
        return self._dual_registers

    @dual_registers.setter
    def dual_registers(self, dual_registers):
        """
        Sets the dual_registers of this PhoneCapabilities.


        :param dual_registers: The dual_registers of this PhoneCapabilities.
        :type: bool
        """
        
        self._dual_registers = dual_registers

    @property
    def hardware_id_type(self):
        """
        Gets the hardware_id_type of this PhoneCapabilities.


        :return: The hardware_id_type of this PhoneCapabilities.
        :rtype: str
        """
        return self._hardware_id_type

    @hardware_id_type.setter
    def hardware_id_type(self, hardware_id_type):
        """
        Sets the hardware_id_type of this PhoneCapabilities.


        :param hardware_id_type: The hardware_id_type of this PhoneCapabilities.
        :type: str
        """
        
        self._hardware_id_type = hardware_id_type

    @property
    def allow_reboot(self):
        """
        Gets the allow_reboot of this PhoneCapabilities.


        :return: The allow_reboot of this PhoneCapabilities.
        :rtype: bool
        """
        return self._allow_reboot

    @allow_reboot.setter
    def allow_reboot(self, allow_reboot):
        """
        Sets the allow_reboot of this PhoneCapabilities.


        :param allow_reboot: The allow_reboot of this PhoneCapabilities.
        :type: bool
        """
        
        self._allow_reboot = allow_reboot

    @property
    def no_rebalance(self):
        """
        Gets the no_rebalance of this PhoneCapabilities.


        :return: The no_rebalance of this PhoneCapabilities.
        :rtype: bool
        """
        return self._no_rebalance

    @no_rebalance.setter
    def no_rebalance(self, no_rebalance):
        """
        Sets the no_rebalance of this PhoneCapabilities.


        :param no_rebalance: The no_rebalance of this PhoneCapabilities.
        :type: bool
        """
        
        self._no_rebalance = no_rebalance

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class DefaultGreetingList(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        DefaultGreetingList - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'owner': 'GreetingOwner',
            'owner_type': 'str',
            'greetings': 'dict(str, Greeting)',
            'created_date': 'datetime',
            'created_by': 'str',
            'modified_date': 'datetime',
            'modified_by': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'owner': 'owner',
            'owner_type': 'ownerType',
            'greetings': 'greetings',
            'created_date': 'createdDate',
            'created_by': 'createdBy',
            'modified_date': 'modifiedDate',
            'modified_by': 'modifiedBy',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._owner = None
        self._owner_type = None
        self._greetings = None
        self._created_date = None
        self._created_by = None
        self._modified_date = None
        self._modified_by = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this DefaultGreetingList.
        The globally unique identifier for the object.

        :return: The id of this DefaultGreetingList.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DefaultGreetingList.
        The globally unique identifier for the object.

        :param id: The id of this DefaultGreetingList.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this DefaultGreetingList.


        :return: The name of this DefaultGreetingList.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this DefaultGreetingList.


        :param name: The name of this DefaultGreetingList.
        :type: str
        """
        
        self._name = name

    @property
    def owner(self):
        """
        Gets the owner of this DefaultGreetingList.


        :return: The owner of this DefaultGreetingList.
        :rtype: GreetingOwner
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """
        Sets the owner of this DefaultGreetingList.


        :param owner: The owner of this DefaultGreetingList.
        :type: GreetingOwner
        """
        
        self._owner = owner

    @property
    def owner_type(self):
        """
        Gets the owner_type of this DefaultGreetingList.


        :return: The owner_type of this DefaultGreetingList.
        :rtype: str
        """
        return self._owner_type

    @owner_type.setter
    def owner_type(self, owner_type):
        """
        Sets the owner_type of this DefaultGreetingList.


        :param owner_type: The owner_type of this DefaultGreetingList.
        :type: str
        """
        allowed_values = ["USER", "ORGANIZATION", "GROUP"]
        if owner_type not in allowed_values:
            raise ValueError(
                "Invalid value for `owner_type`, must be one of {0}"
                .format(allowed_values)
            )

        self._owner_type = owner_type

    @property
    def greetings(self):
        """
        Gets the greetings of this DefaultGreetingList.


        :return: The greetings of this DefaultGreetingList.
        :rtype: dict(str, Greeting)
        """
        return self._greetings

    @greetings.setter
    def greetings(self, greetings):
        """
        Sets the greetings of this DefaultGreetingList.


        :param greetings: The greetings of this DefaultGreetingList.
        :type: dict(str, Greeting)
        """
        
        self._greetings = greetings

    @property
    def created_date(self):
        """
        Gets the created_date of this DefaultGreetingList.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The created_date of this DefaultGreetingList.
        :rtype: datetime
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """
        Sets the created_date of this DefaultGreetingList.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param created_date: The created_date of this DefaultGreetingList.
        :type: datetime
        """
        
        self._created_date = created_date

    @property
    def created_by(self):
        """
        Gets the created_by of this DefaultGreetingList.


        :return: The created_by of this DefaultGreetingList.
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """
        Sets the created_by of this DefaultGreetingList.


        :param created_by: The created_by of this DefaultGreetingList.
        :type: str
        """
        
        self._created_by = created_by

    @property
    def modified_date(self):
        """
        Gets the modified_date of this DefaultGreetingList.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The modified_date of this DefaultGreetingList.
        :rtype: datetime
        """
        return self._modified_date

    @modified_date.setter
    def modified_date(self, modified_date):
        """
        Sets the modified_date of this DefaultGreetingList.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param modified_date: The modified_date of this DefaultGreetingList.
        :type: datetime
        """
        
        self._modified_date = modified_date

    @property
    def modified_by(self):
        """
        Gets the modified_by of this DefaultGreetingList.


        :return: The modified_by of this DefaultGreetingList.
        :rtype: str
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """
        Sets the modified_by of this DefaultGreetingList.


        :param modified_by: The modified_by of this DefaultGreetingList.
        :type: str
        """
        
        self._modified_by = modified_by

    @property
    def self_uri(self):
        """
        Gets the self_uri of this DefaultGreetingList.
        The URI for this object

        :return: The self_uri of this DefaultGreetingList.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this DefaultGreetingList.
        The URI for this object

        :param self_uri: The self_uri of this DefaultGreetingList.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

   ref: https://github.com/swagger-api/swagger-codegen
"""

from __future__ import absolute_import

import os
import sys
import unittest

import swagger_client
from swagger_client.rest import ApiException
from swagger_client.apis.recording_api import RecordingApi


class TestRecordingApi(unittest.TestCase):
    """ RecordingApi unit test stubs """

    def setUp(self):
        self.api = swagger_client.apis.recording_api.RecordingApi()

    def tearDown(self):
        pass

    def test_delete_conversation_id_recordings_recording_id_annotations_annotation_id(self):
        """
        Test case for delete_conversation_id_recordings_recording_id_annotations_annotation_id

        Delete annotation
        """
        pass

    def test_delete_mediaretentionpolicies(self):
        """
        Test case for delete_mediaretentionpolicies

        Delete media retention policies
        """
        pass

    def test_delete_mediaretentionpolicies_policy_id(self):
        """
        Test case for delete_mediaretentionpolicies_policy_id

        Delete a media retention policy
        """
        pass

    def test_delete_orphan_id(self):
        """
        Test case for delete_orphan_id

         deletes a single orphan recording
        """
        pass

    def test_get_conversation_id_recordings(self):
        """
        Test case for get_conversation_id_recordings

        Get all of a Conversation's Recordings.
        """
        pass

    def test_get_conversation_id_recordings_recording_id(self):
        """
        Test case for get_conversation_id_recordings_recording_id

        Gets a specific recording.
        """
        pass

    def test_get_conversation_id_recordings_recording_id_annotations(self):
        """
        Test case for get_conversation_id_recordings_recording_id_annotations

        Get annotations for recording
        """
        pass

    def test_get_conversation_id_recordings_recording_id_annotations_annotation_id(self):
        """
        Test case for get_conversation_id_recordings_recording_id_annotations_annotation_id

        Get annotation
        """
        pass

    def test_get_mediaretentionpolicies(self):
        """
        Test case for get_mediaretentionpolicies

        Gets media retention policy list with query options to filter on name and enabled.
        """
        pass

    def test_get_mediaretentionpolicies_policy_id(self):
        """
        Test case for get_mediaretentionpolicies_policy_id

        Get a media retention policy
        """
        pass

    def test_get_orphan_id(self):
        """
        Test case for get_orphan_id

        Gets a single orphan recording
        """
        pass

    def test_get_orphanrecordings(self):
        """
        Test case for get_orphanrecordings

        Gets all orphan recordings
        """
        pass

    def test_get_settings(self):
        """
        Test case for get_settings

        Get the Recording Settings for the Organization
        """
        pass

    def test_gets_screensessions(self):
        """
        Test case for gets_screensessions

        Retrieves a paged listing of screen recording sessions
        """
        pass

    def test_patch_mediaretentionpolicies_policy_id(self):
        """
        Test case for patch_mediaretentionpolicies_policy_id

        Patch a media retention policy
        """
        pass

    def test_post_conversation_id_recordings_recording_id_annotations(self):
        """
        Test case for post_conversation_id_recordings_recording_id_annotations

        Create annotation
        """
        pass

    def test_post_mediaretentionpolicies(self):
        """
        Test case for post_mediaretentionpolicies

        Create media retention policy
        """
        pass

    def test_put_conversation_id_recordings_recording_id(self):
        """
        Test case for put_conversation_id_recordings_recording_id

        Updates the retention records on a recording.
        """
        pass

    def test_put_conversation_id_recordings_recording_id_annotations_annotation_id(self):
        """
        Test case for put_conversation_id_recordings_recording_id_annotations_annotation_id

        Update annotation
        """
        pass

    def test_put_mediaretentionpolicies_policy_id(self):
        """
        Test case for put_mediaretentionpolicies_policy_id

        Update a media retention policy
        """
        pass

    def test_put_settings(self):
        """
        Test case for put_settings

        Update the Recording Settings for the Organization
        """
        pass


if __name__ == '__main__':
    unittest.main()


# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class DocumentUpdate(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        DocumentUpdate - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'change_number': 'int',
            'name': 'str',
            'read': 'bool',
            'add_tags': 'list[str]',
            'remove_tags': 'list[str]',
            'add_tag_ids': 'list[str]',
            'remove_tag_ids': 'list[str]',
            'update_attributes': 'list[DocumentAttribute]',
            'remove_attributes': 'list[str]'
        }

        self.attribute_map = {
            'change_number': 'changeNumber',
            'name': 'name',
            'read': 'read',
            'add_tags': 'addTags',
            'remove_tags': 'removeTags',
            'add_tag_ids': 'addTagIds',
            'remove_tag_ids': 'removeTagIds',
            'update_attributes': 'updateAttributes',
            'remove_attributes': 'removeAttributes'
        }

        self._change_number = None
        self._name = None
        self._read = False
        self._add_tags = None
        self._remove_tags = None
        self._add_tag_ids = None
        self._remove_tag_ids = None
        self._update_attributes = None
        self._remove_attributes = None

    @property
    def change_number(self):
        """
        Gets the change_number of this DocumentUpdate.


        :return: The change_number of this DocumentUpdate.
        :rtype: int
        """
        return self._change_number

    @change_number.setter
    def change_number(self, change_number):
        """
        Sets the change_number of this DocumentUpdate.


        :param change_number: The change_number of this DocumentUpdate.
        :type: int
        """
        
        self._change_number = change_number

    @property
    def name(self):
        """
        Gets the name of this DocumentUpdate.


        :return: The name of this DocumentUpdate.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this DocumentUpdate.


        :param name: The name of this DocumentUpdate.
        :type: str
        """
        
        self._name = name

    @property
    def read(self):
        """
        Gets the read of this DocumentUpdate.


        :return: The read of this DocumentUpdate.
        :rtype: bool
        """
        return self._read

    @read.setter
    def read(self, read):
        """
        Sets the read of this DocumentUpdate.


        :param read: The read of this DocumentUpdate.
        :type: bool
        """
        
        self._read = read

    @property
    def add_tags(self):
        """
        Gets the add_tags of this DocumentUpdate.


        :return: The add_tags of this DocumentUpdate.
        :rtype: list[str]
        """
        return self._add_tags

    @add_tags.setter
    def add_tags(self, add_tags):
        """
        Sets the add_tags of this DocumentUpdate.


        :param add_tags: The add_tags of this DocumentUpdate.
        :type: list[str]
        """
        
        self._add_tags = add_tags

    @property
    def remove_tags(self):
        """
        Gets the remove_tags of this DocumentUpdate.


        :return: The remove_tags of this DocumentUpdate.
        :rtype: list[str]
        """
        return self._remove_tags

    @remove_tags.setter
    def remove_tags(self, remove_tags):
        """
        Sets the remove_tags of this DocumentUpdate.


        :param remove_tags: The remove_tags of this DocumentUpdate.
        :type: list[str]
        """
        
        self._remove_tags = remove_tags

    @property
    def add_tag_ids(self):
        """
        Gets the add_tag_ids of this DocumentUpdate.


        :return: The add_tag_ids of this DocumentUpdate.
        :rtype: list[str]
        """
        return self._add_tag_ids

    @add_tag_ids.setter
    def add_tag_ids(self, add_tag_ids):
        """
        Sets the add_tag_ids of this DocumentUpdate.


        :param add_tag_ids: The add_tag_ids of this DocumentUpdate.
        :type: list[str]
        """
        
        self._add_tag_ids = add_tag_ids

    @property
    def remove_tag_ids(self):
        """
        Gets the remove_tag_ids of this DocumentUpdate.


        :return: The remove_tag_ids of this DocumentUpdate.
        :rtype: list[str]
        """
        return self._remove_tag_ids

    @remove_tag_ids.setter
    def remove_tag_ids(self, remove_tag_ids):
        """
        Sets the remove_tag_ids of this DocumentUpdate.


        :param remove_tag_ids: The remove_tag_ids of this DocumentUpdate.
        :type: list[str]
        """
        
        self._remove_tag_ids = remove_tag_ids

    @property
    def update_attributes(self):
        """
        Gets the update_attributes of this DocumentUpdate.


        :return: The update_attributes of this DocumentUpdate.
        :rtype: list[DocumentAttribute]
        """
        return self._update_attributes

    @update_attributes.setter
    def update_attributes(self, update_attributes):
        """
        Sets the update_attributes of this DocumentUpdate.


        :param update_attributes: The update_attributes of this DocumentUpdate.
        :type: list[DocumentAttribute]
        """
        
        self._update_attributes = update_attributes

    @property
    def remove_attributes(self):
        """
        Gets the remove_attributes of this DocumentUpdate.


        :return: The remove_attributes of this DocumentUpdate.
        :rtype: list[str]
        """
        return self._remove_attributes

    @remove_attributes.setter
    def remove_attributes(self, remove_attributes):
        """
        Sets the remove_attributes of this DocumentUpdate.


        :param remove_attributes: The remove_attributes of this DocumentUpdate.
        :type: list[str]
        """
        
        self._remove_attributes = remove_attributes

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class EdgeInterface(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        EdgeInterface - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'type': 'str',
            'ip_address': 'str',
            'name': 'str',
            'mac_address': 'str',
            'if_name': 'str',
            'endpoints': 'list[UriReference]',
            'line_types': 'list[str]',
            'address_family_id': 'str'
        }

        self.attribute_map = {
            'type': 'type',
            'ip_address': 'ipAddress',
            'name': 'name',
            'mac_address': 'macAddress',
            'if_name': 'ifName',
            'endpoints': 'endpoints',
            'line_types': 'lineTypes',
            'address_family_id': 'addressFamilyId'
        }

        self._type = None
        self._ip_address = None
        self._name = None
        self._mac_address = None
        self._if_name = None
        self._endpoints = None
        self._line_types = None
        self._address_family_id = None

    @property
    def type(self):
        """
        Gets the type of this EdgeInterface.


        :return: The type of this EdgeInterface.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this EdgeInterface.


        :param type: The type of this EdgeInterface.
        :type: str
        """
        
        self._type = type

    @property
    def ip_address(self):
        """
        Gets the ip_address of this EdgeInterface.


        :return: The ip_address of this EdgeInterface.
        :rtype: str
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address):
        """
        Sets the ip_address of this EdgeInterface.


        :param ip_address: The ip_address of this EdgeInterface.
        :type: str
        """
        
        self._ip_address = ip_address

    @property
    def name(self):
        """
        Gets the name of this EdgeInterface.


        :return: The name of this EdgeInterface.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this EdgeInterface.


        :param name: The name of this EdgeInterface.
        :type: str
        """
        
        self._name = name

    @property
    def mac_address(self):
        """
        Gets the mac_address of this EdgeInterface.


        :return: The mac_address of this EdgeInterface.
        :rtype: str
        """
        return self._mac_address

    @mac_address.setter
    def mac_address(self, mac_address):
        """
        Sets the mac_address of this EdgeInterface.


        :param mac_address: The mac_address of this EdgeInterface.
        :type: str
        """
        
        self._mac_address = mac_address

    @property
    def if_name(self):
        """
        Gets the if_name of this EdgeInterface.


        :return: The if_name of this EdgeInterface.
        :rtype: str
        """
        return self._if_name

    @if_name.setter
    def if_name(self, if_name):
        """
        Sets the if_name of this EdgeInterface.


        :param if_name: The if_name of this EdgeInterface.
        :type: str
        """
        
        self._if_name = if_name

    @property
    def endpoints(self):
        """
        Gets the endpoints of this EdgeInterface.


        :return: The endpoints of this EdgeInterface.
        :rtype: list[UriReference]
        """
        return self._endpoints

    @endpoints.setter
    def endpoints(self, endpoints):
        """
        Sets the endpoints of this EdgeInterface.


        :param endpoints: The endpoints of this EdgeInterface.
        :type: list[UriReference]
        """
        
        self._endpoints = endpoints

    @property
    def line_types(self):
        """
        Gets the line_types of this EdgeInterface.


        :return: The line_types of this EdgeInterface.
        :rtype: list[str]
        """
        return self._line_types

    @line_types.setter
    def line_types(self, line_types):
        """
        Sets the line_types of this EdgeInterface.


        :param line_types: The line_types of this EdgeInterface.
        :type: list[str]
        """
        
        self._line_types = line_types

    @property
    def address_family_id(self):
        """
        Gets the address_family_id of this EdgeInterface.


        :return: The address_family_id of this EdgeInterface.
        :rtype: str
        """
        return self._address_family_id

    @address_family_id.setter
    def address_family_id(self, address_family_id):
        """
        Sets the address_family_id of this EdgeInterface.


        :param address_family_id: The address_family_id of this EdgeInterface.
        :type: str
        """
        
        self._address_family_id = address_family_id

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class Calibration(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Calibration - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'calibrator': 'User',
            'agent': 'User',
            'conversation': 'Conversation',
            'evaluation_form': 'EvaluationForm',
            'context_id': 'str',
            'average_score': 'int',
            'high_score': 'int',
            'low_score': 'int',
            'created_date': 'datetime',
            'evaluations': 'list[Evaluation]',
            'evaluators': 'list[User]',
            'scoring_index': 'Evaluation',
            'expert_evaluator': 'User',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'calibrator': 'calibrator',
            'agent': 'agent',
            'conversation': 'conversation',
            'evaluation_form': 'evaluationForm',
            'context_id': 'contextId',
            'average_score': 'averageScore',
            'high_score': 'highScore',
            'low_score': 'lowScore',
            'created_date': 'createdDate',
            'evaluations': 'evaluations',
            'evaluators': 'evaluators',
            'scoring_index': 'scoringIndex',
            'expert_evaluator': 'expertEvaluator',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._calibrator = None
        self._agent = None
        self._conversation = None
        self._evaluation_form = None
        self._context_id = None
        self._average_score = None
        self._high_score = None
        self._low_score = None
        self._created_date = None
        self._evaluations = None
        self._evaluators = None
        self._scoring_index = None
        self._expert_evaluator = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this Calibration.
        The globally unique identifier for the object.

        :return: The id of this Calibration.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Calibration.
        The globally unique identifier for the object.

        :param id: The id of this Calibration.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this Calibration.


        :return: The name of this Calibration.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Calibration.


        :param name: The name of this Calibration.
        :type: str
        """
        
        self._name = name

    @property
    def calibrator(self):
        """
        Gets the calibrator of this Calibration.


        :return: The calibrator of this Calibration.
        :rtype: User
        """
        return self._calibrator

    @calibrator.setter
    def calibrator(self, calibrator):
        """
        Sets the calibrator of this Calibration.


        :param calibrator: The calibrator of this Calibration.
        :type: User
        """
        
        self._calibrator = calibrator

    @property
    def agent(self):
        """
        Gets the agent of this Calibration.


        :return: The agent of this Calibration.
        :rtype: User
        """
        return self._agent

    @agent.setter
    def agent(self, agent):
        """
        Sets the agent of this Calibration.


        :param agent: The agent of this Calibration.
        :type: User
        """
        
        self._agent = agent

    @property
    def conversation(self):
        """
        Gets the conversation of this Calibration.


        :return: The conversation of this Calibration.
        :rtype: Conversation
        """
        return self._conversation

    @conversation.setter
    def conversation(self, conversation):
        """
        Sets the conversation of this Calibration.


        :param conversation: The conversation of this Calibration.
        :type: Conversation
        """
        
        self._conversation = conversation

    @property
    def evaluation_form(self):
        """
        Gets the evaluation_form of this Calibration.


        :return: The evaluation_form of this Calibration.
        :rtype: EvaluationForm
        """
        return self._evaluation_form

    @evaluation_form.setter
    def evaluation_form(self, evaluation_form):
        """
        Sets the evaluation_form of this Calibration.


        :param evaluation_form: The evaluation_form of this Calibration.
        :type: EvaluationForm
        """
        
        self._evaluation_form = evaluation_form

    @property
    def context_id(self):
        """
        Gets the context_id of this Calibration.


        :return: The context_id of this Calibration.
        :rtype: str
        """
        return self._context_id

    @context_id.setter
    def context_id(self, context_id):
        """
        Sets the context_id of this Calibration.


        :param context_id: The context_id of this Calibration.
        :type: str
        """
        
        self._context_id = context_id

    @property
    def average_score(self):
        """
        Gets the average_score of this Calibration.


        :return: The average_score of this Calibration.
        :rtype: int
        """
        return self._average_score

    @average_score.setter
    def average_score(self, average_score):
        """
        Sets the average_score of this Calibration.


        :param average_score: The average_score of this Calibration.
        :type: int
        """
        
        self._average_score = average_score

    @property
    def high_score(self):
        """
        Gets the high_score of this Calibration.


        :return: The high_score of this Calibration.
        :rtype: int
        """
        return self._high_score

    @high_score.setter
    def high_score(self, high_score):
        """
        Sets the high_score of this Calibration.


        :param high_score: The high_score of this Calibration.
        :type: int
        """
        
        self._high_score = high_score

    @property
    def low_score(self):
        """
        Gets the low_score of this Calibration.


        :return: The low_score of this Calibration.
        :rtype: int
        """
        return self._low_score

    @low_score.setter
    def low_score(self, low_score):
        """
        Sets the low_score of this Calibration.


        :param low_score: The low_score of this Calibration.
        :type: int
        """
        
        self._low_score = low_score

    @property
    def created_date(self):
        """
        Gets the created_date of this Calibration.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The created_date of this Calibration.
        :rtype: datetime
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """
        Sets the created_date of this Calibration.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param created_date: The created_date of this Calibration.
        :type: datetime
        """
        
        self._created_date = created_date

    @property
    def evaluations(self):
        """
        Gets the evaluations of this Calibration.


        :return: The evaluations of this Calibration.
        :rtype: list[Evaluation]
        """
        return self._evaluations

    @evaluations.setter
    def evaluations(self, evaluations):
        """
        Sets the evaluations of this Calibration.


        :param evaluations: The evaluations of this Calibration.
        :type: list[Evaluation]
        """
        
        self._evaluations = evaluations

    @property
    def evaluators(self):
        """
        Gets the evaluators of this Calibration.


        :return: The evaluators of this Calibration.
        :rtype: list[User]
        """
        return self._evaluators

    @evaluators.setter
    def evaluators(self, evaluators):
        """
        Sets the evaluators of this Calibration.


        :param evaluators: The evaluators of this Calibration.
        :type: list[User]
        """
        
        self._evaluators = evaluators

    @property
    def scoring_index(self):
        """
        Gets the scoring_index of this Calibration.


        :return: The scoring_index of this Calibration.
        :rtype: Evaluation
        """
        return self._scoring_index

    @scoring_index.setter
    def scoring_index(self, scoring_index):
        """
        Sets the scoring_index of this Calibration.


        :param scoring_index: The scoring_index of this Calibration.
        :type: Evaluation
        """
        
        self._scoring_index = scoring_index

    @property
    def expert_evaluator(self):
        """
        Gets the expert_evaluator of this Calibration.


        :return: The expert_evaluator of this Calibration.
        :rtype: User
        """
        return self._expert_evaluator

    @expert_evaluator.setter
    def expert_evaluator(self, expert_evaluator):
        """
        Sets the expert_evaluator of this Calibration.


        :param expert_evaluator: The expert_evaluator of this Calibration.
        :type: User
        """
        
        self._expert_evaluator = expert_evaluator

    @property
    def self_uri(self):
        """
        Gets the self_uri of this Calibration.
        The URI for this object

        :return: The self_uri of this Calibration.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this Calibration.
        The URI for this object

        :param self_uri: The self_uri of this Calibration.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class AnalyticsQueryPredicate(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        AnalyticsQueryPredicate - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'type': 'str',
            'dimension': 'str',
            'property_type': 'str',
            'pcProperty': 'str',
            'metric': 'str',
            'operator': 'str',
            'value': 'str',
            'range': 'NumericRange'
        }

        self.attribute_map = {
            'type': 'type',
            'dimension': 'dimension',
            'property_type': 'propertyType',
            'pcProperty': 'property',
            'metric': 'metric',
            'operator': 'operator',
            'value': 'value',
            'range': 'range'
        }

        self._type = None
        self._dimension = None
        self._property_type = None
        self._pcProperty = None
        self._metric = None
        self._operator = None
        self._value = None
        self._range = None

    @property
    def type(self):
        """
        Gets the type of this AnalyticsQueryPredicate.
        Optional type, can usually be inferred

        :return: The type of this AnalyticsQueryPredicate.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this AnalyticsQueryPredicate.
        Optional type, can usually be inferred

        :param type: The type of this AnalyticsQueryPredicate.
        :type: str
        """
        allowed_values = ["dimension", "property", "metric"]
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type`, must be one of {0}"
                .format(allowed_values)
            )

        self._type = type

    @property
    def dimension(self):
        """
        Gets the dimension of this AnalyticsQueryPredicate.
        Left hand side for dimension predicates

        :return: The dimension of this AnalyticsQueryPredicate.
        :rtype: str
        """
        return self._dimension

    @dimension.setter
    def dimension(self, dimension):
        """
        Sets the dimension of this AnalyticsQueryPredicate.
        Left hand side for dimension predicates

        :param dimension: The dimension of this AnalyticsQueryPredicate.
        :type: str
        """
        allowed_values = ["conversationId", "sessionId", "mediaType", "queueId", "userId", "participantId", "participantName", "direction", "wrapUpCode", "wrapUpNote", "interactionType", "requestedRoutingSkillId", "requestedLanguageId", "purpose", "participantType", "segmentType", "disconnectType", "errorCode", "stationId", "edgeId", "dnis", "ani", "outboundCampaignId", "outboundContactId", "outboundContactListId", "monitoredParticipantId", "sourceSessionId", "destinationSessionId", "sourceConversationId", "destinationConversationId", "remoteNameDisplayable", "sipResponseCode", "q850ResponseCode", "conference", "groupId", "roomId", "addressFrom", "addressTo", "peerId", "scriptId", "evaluationId", "evaluatorId", "contextId", "formId", "formName", "eventTime"]
        if dimension not in allowed_values:
            raise ValueError(
                "Invalid value for `dimension`, must be one of {0}"
                .format(allowed_values)
            )

        self._dimension = dimension

    @property
    def property_type(self):
        """
        Gets the property_type of this AnalyticsQueryPredicate.
        Left hand side for property predicates

        :return: The property_type of this AnalyticsQueryPredicate.
        :rtype: str
        """
        return self._property_type

    @property_type.setter
    def property_type(self, property_type):
        """
        Sets the property_type of this AnalyticsQueryPredicate.
        Left hand side for property predicates

        :param property_type: The property_type of this AnalyticsQueryPredicate.
        :type: str
        """
        allowed_values = ["bool", "integer", "real", "date", "string", "uuid"]
        if property_type not in allowed_values:
            raise ValueError(
                "Invalid value for `property_type`, must be one of {0}"
                .format(allowed_values)
            )

        self._property_type = property_type

    @property
    def pcProperty(self):
        """
        Gets the pcProperty of this AnalyticsQueryPredicate.
        Left hand side for property predicates

        :return: The pcProperty of this AnalyticsQueryPredicate.
        :rtype: str
        """
        return self._pcProperty

    @pcProperty.setter
    def pcProperty(self, pcProperty):
        """
        Sets the pcProperty of this AnalyticsQueryPredicate.
        Left hand side for property predicates

        :param pcProperty: The pcProperty of this AnalyticsQueryPredicate.
        :type: str
        """
        
        self._pcProperty = pcProperty

    @property
    def metric(self):
        """
        Gets the metric of this AnalyticsQueryPredicate.
        Left hand side for metric predicates

        :return: The metric of this AnalyticsQueryPredicate.
        :rtype: str
        """
        return self._metric

    @metric.setter
    def metric(self, metric):
        """
        Sets the metric of this AnalyticsQueryPredicate.
        Left hand side for metric predicates

        :param metric: The metric of this AnalyticsQueryPredicate.
        :type: str
        """
        allowed_values = ["tSegmentDuration", "oTotalCriticalScore", "oTotalScore", "nEvaluations", "tAbandon", "tIvr", "tAnswered", "tAcd", "tTalk", "tHeld", "tTalkComplete", "tHeldComplete", "tAcw", "tHandle", "tWait", "tAgentRoutingStatus", "tOrganizationPresence", "tSystemPresence", "tUserResponseTime", "tAgentResponseTime", "nOffered", "nOverSla", "nTransferred", "nOutboundAttempted", "nOutboundConnected", "nOutboundAbandoned", "nError", "oServiceTarget", "oServiceLevel", "tActive", "tInactive", "oActiveUsers", "oMemberUsers", "oActiveQueues", "oMemberQueues", "oInteracting", "oWaiting", "oOnQueueUsers", "oOffQueueUsers"]
        if metric not in allowed_values:
            raise ValueError(
                "Invalid value for `metric`, must be one of {0}"
                .format(allowed_values)
            )

        self._metric = metric

    @property
    def operator(self):
        """
        Gets the operator of this AnalyticsQueryPredicate.
        Optional operator, default is matches

        :return: The operator of this AnalyticsQueryPredicate.
        :rtype: str
        """
        return self._operator

    @operator.setter
    def operator(self, operator):
        """
        Sets the operator of this AnalyticsQueryPredicate.
        Optional operator, default is matches

        :param operator: The operator of this AnalyticsQueryPredicate.
        :type: str
        """
        allowed_values = ["matches", "exists", "notExists"]
        if operator not in allowed_values:
            raise ValueError(
                "Invalid value for `operator`, must be one of {0}"
                .format(allowed_values)
            )

        self._operator = operator

    @property
    def value(self):
        """
        Gets the value of this AnalyticsQueryPredicate.
        Right hand side for dimension, property, or metric predicates

        :return: The value of this AnalyticsQueryPredicate.
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this AnalyticsQueryPredicate.
        Right hand side for dimension, property, or metric predicates

        :param value: The value of this AnalyticsQueryPredicate.
        :type: str
        """
        
        self._value = value

    @property
    def range(self):
        """
        Gets the range of this AnalyticsQueryPredicate.
        Right hand side for property or metric predicates

        :return: The range of this AnalyticsQueryPredicate.
        :rtype: NumericRange
        """
        return self._range

    @range.setter
    def range(self, range):
        """
        Sets the range of this AnalyticsQueryPredicate.
        Right hand side for property or metric predicates

        :param range: The range of this AnalyticsQueryPredicate.
        :type: NumericRange
        """
        
        self._range = range

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

   ref: https://github.com/swagger-api/swagger-codegen
"""

from __future__ import absolute_import

import os
import sys
import unittest

import swagger_client
from swagger_client.rest import ApiException
from swagger_client.models.voicemail_mailbox_info import VoicemailMailboxInfo


class TestVoicemailMailboxInfo(unittest.TestCase):
    """ VoicemailMailboxInfo unit test stubs """

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testVoicemailMailboxInfo(self):
        """
        Test VoicemailMailboxInfo
        """
        model = swagger_client.models.voicemail_mailbox_info.VoicemailMailboxInfo()


if __name__ == '__main__':
    unittest.main()


# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class AnalyticsQueryAggregation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        AnalyticsQueryAggregation - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'type': 'str',
            'dimension': 'str',
            'metric': 'str',
            'size': 'int',
            'ranges': 'list[AggregationRange]'
        }

        self.attribute_map = {
            'type': 'type',
            'dimension': 'dimension',
            'metric': 'metric',
            'size': 'size',
            'ranges': 'ranges'
        }

        self._type = None
        self._dimension = None
        self._metric = None
        self._size = None
        self._ranges = None

    @property
    def type(self):
        """
        Gets the type of this AnalyticsQueryAggregation.
        Optional type, can usually be inferred

        :return: The type of this AnalyticsQueryAggregation.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this AnalyticsQueryAggregation.
        Optional type, can usually be inferred

        :param type: The type of this AnalyticsQueryAggregation.
        :type: str
        """
        allowed_values = ["termFrequency", "numericRange"]
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type`, must be one of {0}"
                .format(allowed_values)
            )

        self._type = type

    @property
    def dimension(self):
        """
        Gets the dimension of this AnalyticsQueryAggregation.
        For use with termFrequency aggregations

        :return: The dimension of this AnalyticsQueryAggregation.
        :rtype: str
        """
        return self._dimension

    @dimension.setter
    def dimension(self, dimension):
        """
        Sets the dimension of this AnalyticsQueryAggregation.
        For use with termFrequency aggregations

        :param dimension: The dimension of this AnalyticsQueryAggregation.
        :type: str
        """
        
        self._dimension = dimension

    @property
    def metric(self):
        """
        Gets the metric of this AnalyticsQueryAggregation.
        For use with numericRange aggregations

        :return: The metric of this AnalyticsQueryAggregation.
        :rtype: str
        """
        return self._metric

    @metric.setter
    def metric(self, metric):
        """
        Sets the metric of this AnalyticsQueryAggregation.
        For use with numericRange aggregations

        :param metric: The metric of this AnalyticsQueryAggregation.
        :type: str
        """
        
        self._metric = metric

    @property
    def size(self):
        """
        Gets the size of this AnalyticsQueryAggregation.
        For use with termFrequency aggregations

        :return: The size of this AnalyticsQueryAggregation.
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """
        Sets the size of this AnalyticsQueryAggregation.
        For use with termFrequency aggregations

        :param size: The size of this AnalyticsQueryAggregation.
        :type: int
        """
        
        self._size = size

    @property
    def ranges(self):
        """
        Gets the ranges of this AnalyticsQueryAggregation.
        For use with numericRange aggregations

        :return: The ranges of this AnalyticsQueryAggregation.
        :rtype: list[AggregationRange]
        """
        return self._ranges

    @ranges.setter
    def ranges(self, ranges):
        """
        Sets the ranges of this AnalyticsQueryAggregation.
        For use with numericRange aggregations

        :param ranges: The ranges of this AnalyticsQueryAggregation.
        :type: list[AggregationRange]
        """
        
        self._ranges = ranges

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

   ref: https://github.com/swagger-api/swagger-codegen
"""

from __future__ import absolute_import

import os
import sys
import unittest

import swagger_client
from swagger_client.rest import ApiException
from swagger_client.apis.telephony_providers_edge_api import TelephonyProvidersEdgeApi


class TestTelephonyProvidersEdgeApi(unittest.TestCase):
    """ TelephonyProvidersEdgeApi unit test stubs """

    def setUp(self):
        self.api = swagger_client.apis.telephony_providers_edge_api.TelephonyProvidersEdgeApi()

    def tearDown(self):
        pass

    def test_delete_providers_edges_certificateauthorities_certificate_id(self):
        """
        Test case for delete_providers_edges_certificateauthorities_certificate_id

        Delete a certificate authority.
        """
        pass

    def test_delete_providers_edges_didpools_didpool_id(self):
        """
        Test case for delete_providers_edges_didpools_didpool_id

        Delete a DID Pool by ID.
        """
        pass

    def test_delete_providers_edges_edge_id(self):
        """
        Test case for delete_providers_edges_edge_id

        Delete a edge.
        """
        pass

    def test_delete_providers_edges_edge_id_logicalinterfaces_interface_id(self):
        """
        Test case for delete_providers_edges_edge_id_logicalinterfaces_interface_id

        Delete an edge logical interface
        """
        pass

    def test_delete_providers_edges_edge_id_softwareupdate(self):
        """
        Test case for delete_providers_edges_edge_id_softwareupdate

        Cancels any in-progress update for this edge.
        """
        pass

    def test_delete_providers_edges_edgegroups_edgegroup_id(self):
        """
        Test case for delete_providers_edges_edgegroups_edgegroup_id

        Delete an edge group.
        """
        pass

    def test_delete_providers_edges_endpoints_endpoint_id(self):
        """
        Test case for delete_providers_edges_endpoints_endpoint_id

        Delete endpoint
        """
        pass

    def test_delete_providers_edges_extensionpools_extensionpool_id(self):
        """
        Test case for delete_providers_edges_extensionpools_extensionpool_id

        Delete an extension pool by ID
        """
        pass

    def test_delete_providers_edges_outboundroutes_outboundroute_id(self):
        """
        Test case for delete_providers_edges_outboundroutes_outboundroute_id

        Delete Outbound Route
        """
        pass

    def test_delete_providers_edges_phonebasesettings_phonebase_id(self):
        """
        Test case for delete_providers_edges_phonebasesettings_phonebase_id

        Delete a Phone Base Settings by ID
        """
        pass

    def test_delete_providers_edges_phones_phone_id(self):
        """
        Test case for delete_providers_edges_phones_phone_id

        Delete a Phone by ID
        """
        pass

    def test_delete_providers_edges_sites_site_id(self):
        """
        Test case for delete_providers_edges_sites_site_id

        Delete a Site by ID
        """
        pass

    def test_delete_providers_edges_trunkbasesettings_trunkbasesettings_id(self):
        """
        Test case for delete_providers_edges_trunkbasesettings_trunkbasesettings_id

        Delete a Trunk Base Settings object by ID
        """
        pass

    def test_get_providers_edges(self):
        """
        Test case for get_providers_edges

        Get the list of edges.
        """
        pass

    def test_get_providers_edges_availablelanguages(self):
        """
        Test case for get_providers_edges_availablelanguages

        Get the list of available languages.
        """
        pass

    def test_get_providers_edges_certificateauthorities(self):
        """
        Test case for get_providers_edges_certificateauthorities

        Get the list of certificate authorities.
        """
        pass

    def test_get_providers_edges_certificateauthorities_certificate_id(self):
        """
        Test case for get_providers_edges_certificateauthorities_certificate_id

        Get a certificate authority.
        """
        pass

    def test_get_providers_edges_didpools(self):
        """
        Test case for get_providers_edges_didpools

        Get a listing of DID Pools
        """
        pass

    def test_get_providers_edges_didpools_didpool_id(self):
        """
        Test case for get_providers_edges_didpools_didpool_id

        Get a DID Pool by ID.
        """
        pass

    def test_get_providers_edges_dids(self):
        """
        Test case for get_providers_edges_dids

        Get a listing of DIDs
        """
        pass

    def test_get_providers_edges_dids_did_id(self):
        """
        Test case for get_providers_edges_dids_did_id

        Get a DID by ID.
        """
        pass

    def test_get_providers_edges_edge_id(self):
        """
        Test case for get_providers_edges_edge_id

        Get edge.
        """
        pass

    def test_get_providers_edges_edge_id_lines(self):
        """
        Test case for get_providers_edges_edge_id_lines

        Get the list of lines.
        """
        pass

    def test_get_providers_edges_edge_id_lines_line_id(self):
        """
        Test case for get_providers_edges_edge_id_lines_line_id

        Get line
        """
        pass

    def test_get_providers_edges_edge_id_logicalinterfaces(self):
        """
        Test case for get_providers_edges_edge_id_logicalinterfaces

        Get edge logical interfaces.
        """
        pass

    def test_get_providers_edges_edge_id_logicalinterfaces_interface_id(self):
        """
        Test case for get_providers_edges_edge_id_logicalinterfaces_interface_id

        Get an edge logical interface
        """
        pass

    def test_get_providers_edges_edge_id_logs_jobs_job_id(self):
        """
        Test case for get_providers_edges_edge_id_logs_jobs_job_id

        Get an Edge logs job.
        """
        pass

    def test_get_providers_edges_edge_id_physicalinterfaces(self):
        """
        Test case for get_providers_edges_edge_id_physicalinterfaces

        Retrieve a list of all configured physical interfaces from a specific edge.
        """
        pass

    def test_get_providers_edges_edge_id_physicalinterfaces_interface_id(self):
        """
        Test case for get_providers_edges_edge_id_physicalinterfaces_interface_id

        Get edge physical interface.
        """
        pass

    def test_get_providers_edges_edge_id_softwareupdate(self):
        """
        Test case for get_providers_edges_edge_id_softwareupdate

        Gets software update status information about any edge.
        """
        pass

    def test_get_providers_edges_edge_id_softwareversions(self):
        """
        Test case for get_providers_edges_edge_id_softwareversions

        Gets all the available software versions for this edge.
        """
        pass

    def test_get_providers_edges_edgegroups(self):
        """
        Test case for get_providers_edges_edgegroups

        Get the list of edge groups.
        """
        pass

    def test_get_providers_edges_edgegroups_edgegroup_id(self):
        """
        Test case for get_providers_edges_edgegroups_edgegroup_id

        Get edge group.
        """
        pass

    def test_get_providers_edges_edgeversionreport(self):
        """
        Test case for get_providers_edges_edgeversionreport

        Get the edge version report.
        """
        pass

    def test_get_providers_edges_endpoints(self):
        """
        Test case for get_providers_edges_endpoints

        Get endpoints
        """
        pass

    def test_get_providers_edges_endpoints_endpoint_id(self):
        """
        Test case for get_providers_edges_endpoints_endpoint_id

        Get endpoint
        """
        pass

    def test_get_providers_edges_extensionpools(self):
        """
        Test case for get_providers_edges_extensionpools

        Get a listing of extension pools
        """
        pass

    def test_get_providers_edges_extensionpools_extensionpool_id(self):
        """
        Test case for get_providers_edges_extensionpools_extensionpool_id

        Get an extension pool by ID
        """
        pass

    def test_get_providers_edges_extensions(self):
        """
        Test case for get_providers_edges_extensions

        Get a listing of extensions
        """
        pass

    def test_get_providers_edges_extensions_extension_id(self):
        """
        Test case for get_providers_edges_extensions_extension_id

        Get an extension by ID.
        """
        pass

    def test_get_providers_edges_linebasesettings(self):
        """
        Test case for get_providers_edges_linebasesettings

        Get a listing of line base settings objects
        """
        pass

    def test_get_providers_edges_linebasesettings_linebase_id(self):
        """
        Test case for get_providers_edges_linebasesettings_linebase_id

        Get a line base settings object by ID
        """
        pass

    def test_get_providers_edges_lines(self):
        """
        Test case for get_providers_edges_lines

        Get a list of Lines
        """
        pass

    def test_get_providers_edges_lines_line_id(self):
        """
        Test case for get_providers_edges_lines_line_id

        Get a Line by ID
        """
        pass

    def test_get_providers_edges_lines_template(self):
        """
        Test case for get_providers_edges_lines_template

        Get a Line instance template based on a Line Base Settings object. This object can then be modified and saved as a new Line instance
        """
        pass

    def test_get_providers_edges_outboundroutes(self):
        """
        Test case for get_providers_edges_outboundroutes

        Get outbound routes
        """
        pass

    def test_get_providers_edges_outboundroutes_outboundroute_id(self):
        """
        Test case for get_providers_edges_outboundroutes_outboundroute_id

        Get outbound route
        """
        pass

    def test_get_providers_edges_phonebasesettings(self):
        """
        Test case for get_providers_edges_phonebasesettings

        Get a list of Phone Base Settings objects
        """
        pass

    def test_get_providers_edges_phonebasesettings_availablemetabases(self):
        """
        Test case for get_providers_edges_phonebasesettings_availablemetabases

        Get a list of available makes and models to create a new Phone Base Settings
        """
        pass

    def test_get_providers_edges_phonebasesettings_phonebase_id(self):
        """
        Test case for get_providers_edges_phonebasesettings_phonebase_id

        Get a Phone Base Settings object by ID
        """
        pass

    def test_get_providers_edges_phonebasesettings_template(self):
        """
        Test case for get_providers_edges_phonebasesettings_template

        Get a Phone Base Settings instance template from a given make and model. This object can then be modified and saved as a new Phone Base Settings instance
        """
        pass

    def test_get_providers_edges_phones(self):
        """
        Test case for get_providers_edges_phones

        Get a list of Phone Instances
        """
        pass

    def test_get_providers_edges_phones_phone_id(self):
        """
        Test case for get_providers_edges_phones_phone_id

        Get a Phone by ID
        """
        pass

    def test_get_providers_edges_phones_template(self):
        """
        Test case for get_providers_edges_phones_template

        Get a Phone instance template based on a Phone Base Settings object. This object can then be modified and saved as a new Phone instance
        """
        pass

    def test_get_providers_edges_sites(self):
        """
        Test case for get_providers_edges_sites

        Get the list of Sites.
        """
        pass

    def test_get_providers_edges_sites_site_id(self):
        """
        Test case for get_providers_edges_sites_site_id

        Get a Site by ID.
        """
        pass

    def test_get_providers_edges_sites_site_id_numberplans(self):
        """
        Test case for get_providers_edges_sites_site_id_numberplans

        Get the list of Number Plans for this Site.
        """
        pass

    def test_get_providers_edges_sites_site_id_numberplans_classifications(self):
        """
        Test case for get_providers_edges_sites_site_id_numberplans_classifications

        Get a list of Classifications for this Site
        """
        pass

    def test_get_providers_edges_sites_site_id_numberplans_numberplan_id(self):
        """
        Test case for get_providers_edges_sites_site_id_numberplans_numberplan_id

        Get a Number Plan by ID.
        """
        pass

    def test_get_providers_edges_timezones(self):
        """
        Test case for get_providers_edges_timezones

        Get a list of Edge-compatible time zones
        """
        pass

    def test_get_providers_edges_trunkbasesettings(self):
        """
        Test case for get_providers_edges_trunkbasesettings

        Get Trunk Base Settings listing
        """
        pass

    def test_get_providers_edges_trunkbasesettings_availablemetabases(self):
        """
        Test case for get_providers_edges_trunkbasesettings_availablemetabases

        Get a list of available makes and models to create a new Trunk Base Settings
        """
        pass

    def test_get_providers_edges_trunkbasesettings_template(self):
        """
        Test case for get_providers_edges_trunkbasesettings_template

        Get a Trunk Base Settings instance template from a given make and model. This object can then be modified and saved as a new Trunk Base Settings instance
        """
        pass

    def test_get_providers_edges_trunkbasesettings_trunkbasesettings_id(self):
        """
        Test case for get_providers_edges_trunkbasesettings_trunkbasesettings_id

        Get a Trunk Base Settings object by ID
        """
        pass

    def test_get_providers_edges_trunks(self):
        """
        Test case for get_providers_edges_trunks

        Get the list of available trunks.
        """
        pass

    def test_get_providers_edges_trunks_trunk_id(self):
        """
        Test case for get_providers_edges_trunks_trunk_id

        Get a Trunk by ID
        """
        pass

    def test_get_providers_edges_trunkswithrecording(self):
        """
        Test case for get_providers_edges_trunkswithrecording

        Get Counts of trunks that have recording disabled or enabled
        """
        pass

    def test_get_schemas_edges_vnext(self):
        """
        Test case for get_schemas_edges_vnext

        Lists available schema categories
        """
        pass

    def test_get_schemas_edges_vnext_schemacategory(self):
        """
        Test case for get_schemas_edges_vnext_schemacategory

        List schemas of a specific category
        """
        pass

    def test_get_schemas_edges_vnext_schemacategory_schematype(self):
        """
        Test case for get_schemas_edges_vnext_schemacategory_schematype

        List schemas of a specific category
        """
        pass

    def test_get_schemas_edges_vnext_schemacategory_schematype_schema_id(self):
        """
        Test case for get_schemas_edges_vnext_schemacategory_schematype_schema_id

        Get a json schema
        """
        pass

    def test_get_schemas_edges_vnext_schemacategory_schematype_schema_id_extensiontype_metadata_id(self):
        """
        Test case for get_schemas_edges_vnext_schemacategory_schematype_schema_id_extensiontype_metadata_id

        Get metadata for a schema
        """
        pass

    def test_post_providers_edges(self):
        """
        Test case for post_providers_edges

        Create a edge.
        """
        pass

    def test_post_providers_edges_addressvalidation(self):
        """
        Test case for post_providers_edges_addressvalidation

        Validates a street address
        """
        pass

    def test_post_providers_edges_certificateauthorities(self):
        """
        Test case for post_providers_edges_certificateauthorities

        Create a certificate authority.
        """
        pass

    def test_post_providers_edges_didpools(self):
        """
        Test case for post_providers_edges_didpools

        Create a new DID pool
        """
        pass

    def test_post_providers_edges_edge_id_logicalinterfaces(self):
        """
        Test case for post_providers_edges_edge_id_logicalinterfaces

        Create an edge logical interface.
        """
        pass

    def test_post_providers_edges_edge_id_logs_jobs(self):
        """
        Test case for post_providers_edges_edge_id_logs_jobs

        Create a job to upload a list of Edge logs.
        """
        pass

    def test_post_providers_edges_edge_id_logs_jobs_job_id_upload(self):
        """
        Test case for post_providers_edges_edge_id_logs_jobs_job_id_upload

        Request that the specified fileIds be uploaded from the Edge.
        """
        pass

    def test_post_providers_edges_edge_id_reboot(self):
        """
        Test case for post_providers_edges_edge_id_reboot

        Reboot an Edge
        """
        pass

    def test_post_providers_edges_edge_id_softwareupdate(self):
        """
        Test case for post_providers_edges_edge_id_softwareupdate

        Starts a software update for this edge.
        """
        pass

    def test_post_providers_edges_edge_id_unpair(self):
        """
        Test case for post_providers_edges_edge_id_unpair

        Unpair an Edge
        """
        pass

    def test_post_providers_edges_edgegroups(self):
        """
        Test case for post_providers_edges_edgegroups

        Create an edge group.
        """
        pass

    def test_post_providers_edges_endpoints(self):
        """
        Test case for post_providers_edges_endpoints

        Create endpoint
        """
        pass

    def test_post_providers_edges_extensionpools(self):
        """
        Test case for post_providers_edges_extensionpools

        Create a new extension pool
        """
        pass

    def test_post_providers_edges_outboundroutes(self):
        """
        Test case for post_providers_edges_outboundroutes

        Create outbound rule
        """
        pass

    def test_post_providers_edges_phonebasesettings(self):
        """
        Test case for post_providers_edges_phonebasesettings

        Create a new Phone Base Settings object
        """
        pass

    def test_post_providers_edges_phones(self):
        """
        Test case for post_providers_edges_phones

        Create a new Phone
        """
        pass

    def test_post_providers_edges_phones_phone_id_reboot(self):
        """
        Test case for post_providers_edges_phones_phone_id_reboot

        Reboot a Phone
        """
        pass

    def test_post_providers_edges_phones_reboot(self):
        """
        Test case for post_providers_edges_phones_reboot

        Reboot Multiple Phones
        """
        pass

    def test_post_providers_edges_sites(self):
        """
        Test case for post_providers_edges_sites

        Create a Site.
        """
        pass

    def test_post_providers_edges_sites_site_id_rebalance(self):
        """
        Test case for post_providers_edges_sites_site_id_rebalance

        Triggers the rebalance operation.
        """
        pass

    def test_post_providers_edges_trunkbasesettings(self):
        """
        Test case for post_providers_edges_trunkbasesettings

        Create a Trunk Base Settings object
        """
        pass

    def test_put_providers_edges_certificateauthorities_certificate_id(self):
        """
        Test case for put_providers_edges_certificateauthorities_certificate_id

        Update a certificate authority.
        """
        pass

    def test_put_providers_edges_didpools_didpool_id(self):
        """
        Test case for put_providers_edges_didpools_didpool_id

        Update a DID Pool by ID.
        """
        pass

    def test_put_providers_edges_dids_did_id(self):
        """
        Test case for put_providers_edges_dids_did_id

        Update a DID by ID.
        """
        pass

    def test_put_providers_edges_edge_id(self):
        """
        Test case for put_providers_edges_edge_id

        Update a edge.
        """
        pass

    def test_put_providers_edges_edge_id_lines_line_id(self):
        """
        Test case for put_providers_edges_edge_id_lines_line_id

        Update a line.
        """
        pass

    def test_put_providers_edges_edge_id_logicalinterfaces_interface_id(self):
        """
        Test case for put_providers_edges_edge_id_logicalinterfaces_interface_id

        Update an edge logical interface.
        """
        pass

    def test_put_providers_edges_edgegroups_edgegroup_id(self):
        """
        Test case for put_providers_edges_edgegroups_edgegroup_id

        Update an edge group.
        """
        pass

    def test_put_providers_edges_endpoints_endpoint_id(self):
        """
        Test case for put_providers_edges_endpoints_endpoint_id

        Update endpoint
        """
        pass

    def test_put_providers_edges_extensionpools_extensionpool_id(self):
        """
        Test case for put_providers_edges_extensionpools_extensionpool_id

        Update an extension pool by ID
        """
        pass

    def test_put_providers_edges_extensions_extension_id(self):
        """
        Test case for put_providers_edges_extensions_extension_id

        Update an extension by ID.
        """
        pass

    def test_put_providers_edges_outboundroutes_outboundroute_id(self):
        """
        Test case for put_providers_edges_outboundroutes_outboundroute_id

        Update outbound route
        """
        pass

    def test_put_providers_edges_phonebasesettings_phonebase_id(self):
        """
        Test case for put_providers_edges_phonebasesettings_phonebase_id

        Update a Phone Base Settings by ID
        """
        pass

    def test_put_providers_edges_phones_phone_id(self):
        """
        Test case for put_providers_edges_phones_phone_id

        Update a Phone by ID
        """
        pass

    def test_put_providers_edges_sites_site_id(self):
        """
        Test case for put_providers_edges_sites_site_id

        Update a Site by ID.
        """
        pass

    def test_put_providers_edges_sites_site_id_numberplans(self):
        """
        Test case for put_providers_edges_sites_site_id_numberplans

        Update the list of Number Plans.
        """
        pass

    def test_put_providers_edges_trunkbasesettings_trunkbasesettings_id(self):
        """
        Test case for put_providers_edges_trunkbasesettings_trunkbasesettings_id

        Update a Trunk Base Settings object by ID
        """
        pass


if __name__ == '__main__':
    unittest.main()


# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class FacetEntry(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        FacetEntry - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'attribute': 'TermAttribute',
            'statistics': 'FacetStatistics',
            'other': 'int',
            'total': 'int',
            'missing': 'int',
            'term_count': 'int',
            'term_type': 'str',
            'terms': 'list[FacetTerm]'
        }

        self.attribute_map = {
            'attribute': 'attribute',
            'statistics': 'statistics',
            'other': 'other',
            'total': 'total',
            'missing': 'missing',
            'term_count': 'termCount',
            'term_type': 'termType',
            'terms': 'terms'
        }

        self._attribute = None
        self._statistics = None
        self._other = None
        self._total = None
        self._missing = None
        self._term_count = None
        self._term_type = None
        self._terms = None

    @property
    def attribute(self):
        """
        Gets the attribute of this FacetEntry.


        :return: The attribute of this FacetEntry.
        :rtype: TermAttribute
        """
        return self._attribute

    @attribute.setter
    def attribute(self, attribute):
        """
        Sets the attribute of this FacetEntry.


        :param attribute: The attribute of this FacetEntry.
        :type: TermAttribute
        """
        
        self._attribute = attribute

    @property
    def statistics(self):
        """
        Gets the statistics of this FacetEntry.


        :return: The statistics of this FacetEntry.
        :rtype: FacetStatistics
        """
        return self._statistics

    @statistics.setter
    def statistics(self, statistics):
        """
        Sets the statistics of this FacetEntry.


        :param statistics: The statistics of this FacetEntry.
        :type: FacetStatistics
        """
        
        self._statistics = statistics

    @property
    def other(self):
        """
        Gets the other of this FacetEntry.


        :return: The other of this FacetEntry.
        :rtype: int
        """
        return self._other

    @other.setter
    def other(self, other):
        """
        Sets the other of this FacetEntry.


        :param other: The other of this FacetEntry.
        :type: int
        """
        
        self._other = other

    @property
    def total(self):
        """
        Gets the total of this FacetEntry.


        :return: The total of this FacetEntry.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """
        Sets the total of this FacetEntry.


        :param total: The total of this FacetEntry.
        :type: int
        """
        
        self._total = total

    @property
    def missing(self):
        """
        Gets the missing of this FacetEntry.


        :return: The missing of this FacetEntry.
        :rtype: int
        """
        return self._missing

    @missing.setter
    def missing(self, missing):
        """
        Sets the missing of this FacetEntry.


        :param missing: The missing of this FacetEntry.
        :type: int
        """
        
        self._missing = missing

    @property
    def term_count(self):
        """
        Gets the term_count of this FacetEntry.


        :return: The term_count of this FacetEntry.
        :rtype: int
        """
        return self._term_count

    @term_count.setter
    def term_count(self, term_count):
        """
        Sets the term_count of this FacetEntry.


        :param term_count: The term_count of this FacetEntry.
        :type: int
        """
        
        self._term_count = term_count

    @property
    def term_type(self):
        """
        Gets the term_type of this FacetEntry.


        :return: The term_type of this FacetEntry.
        :rtype: str
        """
        return self._term_type

    @term_type.setter
    def term_type(self, term_type):
        """
        Sets the term_type of this FacetEntry.


        :param term_type: The term_type of this FacetEntry.
        :type: str
        """
        allowed_values = ["TERM", "NUMBERRANGE", "NUMBERHISTOGRAM", "DATERANGE", "DATEHISTOGRAM", "ID"]
        if term_type not in allowed_values:
            raise ValueError(
                "Invalid value for `term_type`, must be one of {0}"
                .format(allowed_values)
            )

        self._term_type = term_type

    @property
    def terms(self):
        """
        Gets the terms of this FacetEntry.


        :return: The terms of this FacetEntry.
        :rtype: list[FacetTerm]
        """
        return self._terms

    @terms.setter
    def terms(self, terms):
        """
        Sets the terms of this FacetEntry.


        :param terms: The terms of this FacetEntry.
        :type: list[FacetTerm]
        """
        
        self._terms = terms

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

